@@ -8,11 +8,11 @@ module Nanoc::CLI
     # Enables error handling in the given block.
     #
     # @return [void]
-    def self.handle_while(exit_on_error: true, &block)
+    def self.handle_while(exit_on_error: true, &)
       if @disabled
         yield
       else
-        new.handle_while(exit_on_error:, &block)
+        new.handle_while(exit_on_error:, &)
       end
     end
 
@@ -107,9 +107,7 @@ module Nanoc::CLI
       write_compact_error(error, $stderr)
 
       File.open('crash.log', 'w') do |io|
-        cio = Nanoc::CLI.wrap_in_cleaning_stream(io)
-        cio.add_stream_cleaner(::Nanoc::CLI::StreamCleaners::ANSIColors)
-        write_verbose_error(error, cio)
+        write_verbose_error(error, io)
       end
     end
 
@@ -205,6 +203,7 @@ module Nanoc::CLI
       'nanoc/live' => 'nanoc-live',
       'nokogiri' => 'nokogiri',
       'pandoc-ruby' => 'pandoc-ruby',
+      'perfect_toml' => 'perfect_toml',
       'pry' => 'pry',
       'rack' => 'rack',
       'rack/cache' => 'rack-cache',
@@ -289,7 +288,7 @@ module Nanoc::CLI
 
       message = "#{error.class}: #{message_for_error(error)}"
       unless verbose
-        message = "\e[1m\e[31m" + message + "\e[0m"
+        message = colorizer_for(stream).c(message, :bold, :red)
       end
       stream.puts message
       resolution = resolution_for(error)
@@ -363,6 +362,10 @@ module Nanoc::CLI
       end
     end
 
+    def colorizer_for(io)
+      Nanoc::CLI::ANSIStringColorizer.new(io)
+    end
+
     def unwrap_error(e)
       case e
       when Nanoc::Core::Errors::CompilationError
