@@ -30,6 +30,6 @@ require_relative 'filters/rubypants'
 require_relative 'filters/sass'
 require_relative 'filters/slim'
 require_relative 'filters/typogruby'
-require_relative 'filters/uglify_js'
+require_relative 'filters/terser'
 require_relative 'filters/xsl'
 require_relative 'filters/yui_compressor'
